@@ -69,9 +69,11 @@ class Counter(statsd.Client):
         self.decrement(delta=delta)
         return self
 
+
 def increment(key):
-    counter = Counter(key).increment()
+    return Counter(key).increment()
+
 
 def decrement(key):
-    counter = Counter(key).decrement()
+    return Counter(key).decrement()
 
